<?php
/**
 * Multipurpose Corporate functions and definitions
 * @package Multipurpose Corporate
 */


/* Theme Setup */
if ( ! function_exists( 'multipurpose_corporate_setup' ) ) :

function multipurpose_corporate_setup() {

	$GLOBALS['content_width'] = apply_filters( 'multipurpose_corporate_content_width', 640 );

	load_theme_textdomain( 'multipurpose-corporate', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('multipurpose-corporate-homepage-thumb',240,145,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'multipurpose-corporate' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	add_editor_style( array( 'assets/css/editor-style.css', multipurpose_corporate_font_url() ) );
}
endif; // multipurpose_corporate_setup
add_action( 'after_setup_theme', 'multipurpose_corporate_setup' );

/*Site URL*/
define('MULTIPURPOSE_CORPORATE_CREDIT','https://www.logicalthemes.com/','multipurpose-corporate');
if ( ! function_exists( 'multipurpose_corporate_credit' ) ) {
	function multipurpose_corporate_credit(){
		echo "<a href=".esc_url(MULTIPURPOSE_CORPORATE_CREDIT)." target='_blank'>".esc_html__('LogicalThemes','multipurpose-corporate')."</a>";
	}
}

/*radio button sanitization*/
function multipurpose_corporate_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Excerpt Limit Begin */
function multipurpose_corporate_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

/* Theme Widgets Setup */
function multipurpose_corporate_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'multipurpose-corporate' ),
		'description'   => __( 'Appears on blog page sidebar', 'multipurpose-corporate' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Posts and Pages Sidebar', 'multipurpose-corporate' ),
		'description'   => __( 'Appears on posts and pages', 'multipurpose-corporate' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'multipurpose-corporate' ),
		'description'   => __( 'Appears on posts and pages', 'multipurpose-corporate' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'multipurpose-corporate' ),
		'description'   => __( 'Appears in footer', 'multipurpose-corporate' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'multipurpose-corporate' ),
		'description'   => __( 'Appears in footer', 'multipurpose-corporate' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'multipurpose-corporate' ),
		'description'   => __( 'Appears in footer', 'multipurpose-corporate' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'multipurpose-corporate' ),
		'description'   => __( 'Appears in footer', 'multipurpose-corporate' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'multipurpose_corporate_widgets_init' );

function multipurpose_corporate_font_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Karla:400,400i,700';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}	

/* Theme enqueue scripts */
function multipurpose_corporate_scripts() {
	wp_enqueue_style( 'multipurpose-corporate-font', multipurpose_corporate_font_url(), array() );
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri() . '/assets/css/bootstrap.css');
	wp_enqueue_style( 'multipurpose-corporate-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'multipurpose-corporate-style', 'rtl', 'replace' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/assets/css/fontawesome-all.css' );
	wp_enqueue_script( 'bootstrap-jquery', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'multipurpose-corporate-custom-jquery', get_template_directory_uri() . '/assets/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'multipurpose_corporate_scripts' );

function multipurpose_corporate_ie_stylesheet(){
	wp_enqueue_style('multipurpose-corporate-ie', get_template_directory_uri().'/assets/css/ie.css', array('multipurpose-corporate-basic-style'));
	wp_style_add_data( 'multipurpose-corporate-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','multipurpose_corporate_ie_stylesheet');

require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/customizer.php';